<?php
session_start();
define('QR_ROOT', dirname(__DIR__));
define('QR_DIR', dirname(__FILE__));
define('SCRIPT_NAME', 'Quranic Researcher');
define('SCRIPT_VERSION', '1.1');

function site_url($url=''){
	$s = $_SERVER;
  $ssl = ( ! empty( $s['HTTPS'] ) && $s['HTTPS'] == 'on' );
  $sp = strtolower( $s['SERVER_PROTOCOL'] );
  $protocol = substr( $sp, 0, strpos( $sp, '/' ) ) . ( ( $ssl ) ? 's' : '' );
  $port = $s['SERVER_PORT'];
  $port = ( ( ! $ssl && $port=='80' ) || ( $ssl && $port=='443' ) ) ? '' : ':'.$port;
  $host = isset( $host ) ? $host : $s['SERVER_NAME'] . $port;
	$folder = explode('/', $s['REQUEST_URI']);
	$newFolder = '';
	foreach ($folder as $key => $value) {
		$value = trim($value);
		if( !empty($value) ){
			if( !preg_match('/\?\b/', $value) ){
				$newFolder .= $value.'/';
			}
		}
	}

	$newFolder = rtrim($newFolder, '/');

  return $protocol . '://' . $host . '/'. $newFolder. ( !empty($url) ? '/'.$url : '' );
}

function current_lang() {
	$getLang = ( isset($_GET['lang']) && $_GET['lang'] == 'en' ? 'en' : 'ar' );
	if( isset($_SESSION['lang']) && !empty($_SESSION['lang']) ){
		if( isset($_GET['lang']) && !empty($_GET['lang']) ){
			$_SESSION['lang'] = strip_tags($_GET['lang']);
			$getLang = $_SESSION['lang'];
		}else{
			$getLang = $_SESSION['lang'];
		}
	}else{
		$_SESSION['lang'] = $getLang;
	}

	return $getLang;
}

function lang($k) {
	global $lang;
	if( current_lang() == 'en' ){
		include_once(QR_ROOT.'/language/en.php');
	}else{
		include_once(QR_ROOT.'/language/ar.php');
	}

	return ( isset($lang[$k]) ? $lang[$k] : 'Not found key ['.$k.']' );
}

function ayah_number(){
	return ['0', '7', '286', '200', '176', '120', '165', '206', '75', '129', '109', '123', '111', '43', '52', '99', '128', '111', '110', '98', '135', '112', '78', '118', '64', '77', '227', '93', '88', '69', '60', '34', '30', '73', '54', '45', '83', '182', '88', '75', '85', '54', '53', '89', '59', '37', '35', '38', '29', '18', '45', '60', '49', '62', '55', '78', '96', '29', '22', '24', '13', '14', '11', '11', '18', '12', '12', '30', '52', '52', '44', '28', '28', '20', '56', '40', '31', '50', '40', '46', '42', '29', '19', '36', '25', '22', '17', '19', '26', '30', '20', '15', '21', '11', '8', '8', '19', '5', '8', '8', '11', '11', '8', '3', '9', '5', '4', '7', '3', '6', '3', '5', '4', '5', '6'];
}

function surah_name(){
	return ['القرآن الكريم','الفاتحة','البقرة','آل عمران','النساء','المائدة','الأنعام','الأعراف','الأنفال','التوبة','يونس' ,'هود','يوسف','الرعد','إبراهيم','الحجر','النحل','الإسراء','الكهف','مريم','طه','الأنبياء','الحج','المؤمنون','النور','الفرقان','الشعراء','النمل' ,'القصص','العنكبوت','الروم','لقمان','السجدة','الأحزاب','سبأ','فاطر','يس','الصافات','ص','الزمر','غافر','فصلت','الشورى','الزخرف','الدخان','الجاثية','الأحقاف' ,'محمد','الفتح','الحجرات','ق','الذاريات','الطور','النجم','القمر','الرحمن','الواقعة','الحديد','المجادلة','الحشر','الممتحنة','الصف','الجمعة','المنافقون','التغابن','الطلاق' ,'التحريم','الملك','القلم','الحاقة','المعارج','نوح','الجن','المزمل','المدثر','القيامة','الإنسان','المرسلات','النبأ','النازعات','عبس','التكوير','الانفطار','المطففين','الانشقاق','البروج','الطارق','الأعلى' ,'الغاشية','الفجر','البلد','الشمس','الليل','الضحى','الشرح','التين','العلق','القدر','البينة','الزلزلة','العاديات','القارعة','التكاثر','العصر','الهمزة','الفيل','قريش','الماعون','الكوثر','الكافرون','النصر','المسد','الإخلاص','الفلق','الناس'];
}

function get_content( $url, $authorization_key='' ){
	$curl = curl_init($url);
	curl_setopt($curl, CURLOPT_URL, $url);
	curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
	if( !empty($authorization_key) ){
		$headers = array(
		   "Accept: application/json",
		   "Authorization: Bearer ".$authorization_key,
		);
		curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
	}

	curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);

	$resp = curl_exec($curl);
	curl_close($curl);

	return $resp;
}

function get_api_result(){
	$text = ( isset($_GET['text']) && trim($_GET['text']) != '' ? strip_tags($_GET['text']) : '' );
	$page = ( isset($_GET['page']) && intval($_GET['page']) > 0 ? intval($_GET['page']) : 1 );

	if( empty($text) ){
		$res = [ 'status' => 'error', 'msg' => lang('empty_word') ];
	}else{
		$url = 'https://api.quran.com/api/v4/search/?q='.$text.'&size=50&page='.$page;
		$data = get_content( $url );
		$response = json_decode($data);

		if ( !empty( $response ) ) {
			$surah_names = surah_name();
			if( is_array($response->search->results) && count($response->search->results) > 0 ){
				$total_results = ( isset($response->search->total_results) ? intval($response->search->total_results) : 0 );
				$current_page = ( isset($response->search->current_page) ? intval($response->search->current_page) : 1 );
				$total_pages = ( isset($response->search->total_pages) ? intval($response->search->total_pages) : 0 );
				$query = ( isset($response->search->query) ? strip_tags($response->search->query) : '' );

				$newArray = [];
				foreach ($response->search->results as $key => $value) {
					$verse_key = ( isset($value->verse_key) ? $value->verse_key : 0 );
					$verse_id = ( isset($value->verse_id) ? $value->verse_id : 0 );
					$text = ( isset($value->text) ? $value->text : '' );
					$highlighted = ( isset($value->highlighted) ? $value->highlighted : '' );

					$surah_id = '';
					$ayah_id = '';
					$surah_url = '';
					$ayah_url = '';
					$surah_name = '';

					if( !empty($verse_key) ){
						$split_match = explode(':', $verse_key);
						$surah_id = ( isset($split_match[0]) ? intval($split_match[0]) : '' );
						$ayah_id = ( isset($split_match[1]) ? intval($split_match[1]) : '' );
						$surah_url = 'https://quran-uni.com/mos-haf/surah/'.$surah_id;
						$ayah_url = 'https://quran-uni.com/mos-haf/tafsir_surah/muyassar/'.$surah_id.'/#ayah-'.$ayah_id;
						$surah_name = ( isset($surah_names[$surah_id]) ? $surah_names[$surah_id] : '' );
					}

					$newArray[] = [
						'surah_name' => $surah_name,
						'surah_id' => $surah_id,
						'ayah_id' => $ayah_id,
						'ayah_id_ar' => arabic_digits($ayah_id),
						'surah_url' => $surah_url,
						'ayah_url' => $ayah_url,
						'text' => $text,
						'verse_id' => $verse_id,
						'highlighted' => $highlighted
					];
				}

				$res = [
					'status' => 'success',
					'total_results' => $total_results,
					'current_page' => $current_page,
					'total_pages' => $total_pages,
					'query' => $query,
					'result' => $newArray
				];
			}else{
				$res = [ 'status' => 'error', 'msg' => lang('not_found') ];
			}

		}else{
			$res = [ 'status' => 'error', 'msg' => lang('error') ];
		}
	}

	echo json_encode( $res );
}

function get_flags(){
	$lang = current_lang();
	$langs = [
		'ar' => lang('arabic'),
		'en' => lang('english')
	];
	$html = '<div class="flags">';
	foreach ($langs as $key => $value) {
		if( $key == $lang ){
			$html .= '<img src="'.site_url('images/'.$key.'.png').'" alt="'.$value.'" title="'.$value.'">';
		}else{
			$html .= '<a href="'.site_url('?lang='.$key).'"><img src="'.site_url('images/'.$key.'.png').'" alt="'.$value.'" title="'.$value.'"></a>';
		}
	}
	$html .= '</div>';
  return $html;
}

function arabic_digits($str){
	$western_arabic = array('0','1','2','3','4','5','6','7','8','9');
	$eastern_arabic = array('٠','١','٢','٣','٤','٥','٦','٧','٨','٩');
	$str = str_replace($western_arabic, $eastern_arabic, $str);
	return $str;
}
?>
